package com.example.nekontakte;

import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.server.ResponseStatusException;

import java.util.HashMap;
import java.util.List;

import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;

@RestController
@RequestMapping("/user")
public class UserApiEndpoint {
    private Integer lastUserId = 0;
    private HashMap<Integer, UserDTO> users = new HashMap<>();

    @GetMapping()
    public List<UserDTO> getUsers() {
        return users.values().stream().toList();
    }

    @GetMapping("/{id}")
    public UserDTO getUser(@PathVariable Integer id) {
        if (users.containsKey(id)) {
            return users.get(id);
        }
        throw new ResponseStatusException(HttpStatus.NOT_FOUND);
    }

    @PostMapping()
    public UserDTO postUser(@RequestBody UserDTO entity) {
        Integer currentUserId = lastUserId + 1;
        entity.setId(currentUserId);
        users.put(currentUserId, entity);
        lastUserId++;
        return entity;
    }

    @PutMapping("/{id}")
    public UserDTO putUser(@PathVariable Integer id, @RequestBody UserDTO entity) {
        if (users.containsKey(id)) {
            entity.setId(id);
            users.put(id, entity);
            return entity;
        }
        throw new ResponseStatusException(HttpStatus.NOT_FOUND);
    }

    @DeleteMapping("/{id}")
    public UserDTO deleteUser(@PathVariable Integer id) {
        if (users.containsKey(id)) {
            return users.remove(id);
        }
        throw new ResponseStatusException(HttpStatus.NOT_FOUND);
    }

}
